==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Kuvat on valokuvien näyttö- ja muokkaustyökalu, jossa on moderni käyttöliittymä ja sujuva työskentely.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Kuvat</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Kuvan tiedot</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Palutus</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Perustiedot</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Tiedot</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Tämä tiedosto sisältää useita sivuja, käytä Evince-ohjelmaa nähdäksesi kaikki sivut.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Avaa hakemisto</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Sinulla ei ole oikeutta tarkastella kuvaa</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Kuvatiedostoa ei löytynyt</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Muokattu</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Mitat</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Kuvauspäivä</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Valotustila</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Valotusohjelma</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Valotusaika</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Salama</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Aukko</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Polttoväli</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maksimi aukko</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mittaustila</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Valkotasapaino</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Salamakompensointi</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Linssin malli</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Värikartta</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameramalli</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Mitat</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tunniste</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Ei skaalausta</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Sovita sivu kuvaan</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Sovita kuva sivulle</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Skaalaa:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimetriä</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Senttimetriä</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Tuumaa:</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Kuvan sijainti</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Skaalaus</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Kuvan asetukset</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Kuvan asetukset</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Kaihtimet</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Vaihtaja</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Liukuva</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Ympyrä</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Anna uusi nimi</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Valitse hakemisto</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Tämän hakemiston synkronointi on poistettu käytöstä</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Lisää kansio</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Synkronointihakemiston hallinta</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Hakemistoluettelo on tyhjä</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Peru synkronointi</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Laite on poistettu</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Tätä hakemistoa ei enää ole</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Lasketaan...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Kuvan katselu</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albumi</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaesitys</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Lopeta diaesitys</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Poista albumista</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikkini</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Poista-suosikki</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Kierrä myötäpäivään</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Kierrä vastapäivään</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Aseta taustakuvaksi</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostonhallinnassa</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kuvan tiedot</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Edellinen</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Edellinen ruutu</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Seuraava ruutu</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uusi albumi</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä pikavalinnat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Poistu koko näytöstä</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Lähennä</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Loitonna</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Anna uusi pikakuvake</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Pikakuvakkeet</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Näytä kuva</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albumi</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Palauta oletukset</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaesitys</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Lopeta diaesitys</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Poista albumista</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikkini</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Poista-suosikki</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Kierrä myötäpäivään</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Kierrä vastapäivään</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Aseta taustakuvaksi</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostonhallinnassa</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kuvan tiedot</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uusi albumi</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Edellinen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tauko</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Toista</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Dian asetukset</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Vaihda efekti</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Kesto</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Säädä kesto</translation>
    </message>
    <message>
        <source>second</source>
        <translation>seuraava</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Suosikkini</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Edellinen</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Koko 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Sovita ikkunaan</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Kierrä vastapäivään</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Kierrä myötäpäivään</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Takaisin</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Kuvanhallinta</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Suosikkini</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Koko 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Sovita ikkunaan</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Kierrä vastapäivään</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Kierrä myötäpäivään</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Poista-suosikki</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikkini</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Kuvia ei löytynyt</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Avaa kuva</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Kuvatiedostoa ei löytynyt</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Dian asetukset</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efekti</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Kesto</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Pikakuvakkeet</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Albumi</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Uusi albumi</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Aikajana</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Lisää albumiin</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Lisää uuteen albumiin</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Poistu koko näytöstä</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaesitys</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Poista albumista</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikkini</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Poista-suosikki</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Näytä navigointiikkuna</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Piilota navigointiikkuna</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Kierrä myötäpäivään</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Kierrä vastapäivään</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Aseta taustakuvaksi</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostonhallinnassa</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kuvan tiedot</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Avaa kuva</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Kaikki kuvat</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Piirtäminen</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.8.15.orig.tar.xz: deepin-image-viewer-5.8.15/src/translations/deepin-image-viewer_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Kuvatiedostoa ei löytynyt</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Avaa kuva</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Kuvan katselu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Poistu koko näytöstä</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Tunnista tekstiksi</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaesitys</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Kierrä myötäpäivään</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Kierrä vastapäivään</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Aseta taustakuvaksi</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostonhallinnassa</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kuvan tiedot</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Edellinen</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Lähennä</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Loitonna</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä pikavalinnat</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Kuvat on valokuvien näyttö- ja muokkaustyökalu, jossa on moderni käyttöliittymä ja sujuva työskentely.</translation>
    </message>
</context>
</TS>
